<p align="center">
<a href="https://tephi.readthedocs.io/en/latest/">
    <img src="https://scitools.github.io/tephi/tephi-logo-200-137.png" alt="Tephi">
</a>
</p>

<p align="center"><strong>Tephigram plotting in Python</strong></p>

<p align="center">
<a href="https://travis-ci.org/github/SciTools/tephi/branches">
    <img src="https://travis-ci.org/SciTools/tephi.svg?branch=master"
        alt="Travis-CI" />
</a>
<a href="https://tephi.readthedocs.io/en/latest/?badge=latest">
    <img src="https://readthedocs.org/projects/tephi/badge/?version=latest"
        alt="Documentation Status" />
</a>
<a href="https://coveralls.io/github/SciTools/tephi?branch=master">
    <img src="https://coveralls.io/repos/github/SciTools/tephi/badge.svg?branch=master"
        alt="Coverage Status" />
</a>
<a href="https://github.com/SciTools/tephi/releases">
    <img src="https://img.shields.io/github/v/tag/scitools/tephi?color=orange"
        alt="GitHub tag (latest by date)" />
</a>
<a href="https://github.com/SciTools/tephi/commits/master">
    <img src="https://img.shields.io/github/commits-since/scitools/tephi/latest/master"
        alt="GitHub commits since tagged version" />
</a>
<a href="https://pypi.org/project/tephi/">
    <img src="https://img.shields.io/pypi/v/tephi"
        alt="PyPI" />
</a>
<a href="https://mybinder.org/v2/gh/SciTools/tephi/master?filepath=index.ipynb">
    <img src="https://mybinder.org/badge_logo.svg"
        alt="Launch MyBinderk" />
</a>
<a href="https://github.com/psf/black">
    <img src="https://img.shields.io/badge/code/style-black-000000.svg"
         alt="Black" />
</a>
</p>

<br>

© British Crown Copyright 2014-2020, Met Office

